/*******************************************************************
 * Fritz Fun                                                       *
 * Created by Jan-Michael Brummer &  Louis Lagendijk               * 
 * All parts are distributed under the terms of GPLv2. See COPYING *
 *******************************************************************/

/**
 * \file ab_ebook.c
 * \brief Evolution address book plugin
 */
#include <libedataserver/eds-version.h>

// #include <libebook/e-book.h>
// #include <libebook/e-contact.h>
// #include <libebook/e-book-query.h>
#include <libebook/e-book-client.h>
// #include <libebook/e-book-query.h>
#include <ab_ebook/ebook-sources.h>
#include <ffgtk.h>
#include <addressbook.h>

/**
 *\brief Retrieve the uid for the source
 *\param The source
 *\return the uid of the source
 */
const gchar *getEbookId( ESource *psEsource ) {
	return e_source_get_uri( psEsource );
}

/**
 * \brief Retrieve the display name for the source
 * \param The source
 * \return the display name of the source
 */
const gchar *getEbookName( ESource *psEsource ) {
	return e_source_peek_name( psEsource );
}

/**
 * \brief Get selected evolution address book
 * \return evolution address book Id
 */
const gchar *getSelectedEbookId( void ) {
        return prefsGetString( getActiveProfile(), "/plugins/evolution/book" );
}

/**
 * \brief Set selected evolution address book
 * \param pnUri evolution address book
 */
void setSelectedEbookId( const gchar *pnId ) {
	prefsSetString( getActiveProfile(), "/plugins/evolution/book", pnId );
}

/**
 * \brief Get client for active address book
 * \return ebook client
 */
EBookClient  *getSelectedEbookClient() {
	EBookClient *psClient;
	GError *psError = NULL;
        const gchar *pnUri = NULL;
        pnUri = getSelectedEbookId();
        if ( pnUri == NULL || strlen( pnUri ) == 0 ) {
                psClient = e_book_client_new_system( &psError );
        } else {
                psClient = e_book_client_new_from_uri( pnUri, &psError );
        }
	return psClient;
}

GList *getEbooksList( void ) {
	ESourceList *psAddressbooks;
	GSList *psGroups, *psGroup;
	GSList *psSources, *psSource;
	GList *psEbooksList = NULL;
	struct sEbookData *psEbookData = NULL;
	GError *psError;

	if ( !e_book_client_get_sources( &psAddressbooks, &psError ) ) {
		Debug( KERN_WARNING, "Could not retrieve addressbooks, abort!\n" );
		return NULL;
	}
	
	psGroups = e_source_list_peek_groups( psAddressbooks );
	if ( psGroups == NULL ) {
		Debug( KERN_WARNING, "No groups!\n" );
		return NULL;
	}
	for ( psGroup = psGroups; psGroup != NULL; psGroup = psGroup -> next ) {

		psSources = e_source_group_peek_sources( psGroup -> data );
		for ( psSource = psSources; psSource != NULL; psSource = psSource -> next ) {
			ESource *psESource = E_SOURCE( psSource -> data );
			psEbookData = g_new( struct sEbookData, 1);
			psEbookData -> pnEbookName = g_strdup( getEbookName( psESource  ) );
			psEbookData -> pnEbookId = g_strdup( getEbookId ( psESource ) );

			psEbooksList = g_list_append( psEbooksList, psEbookData );
		}
	}
	return psEbooksList;
}
	

/**
 *\brief free data allocated for an address book data item
 *\param ebook data item to be destroyed
 */
static void freeEbookData( struct sEbookData *psEbookData ) {
        g_free( psEbookData -> pnEbookName );
        g_free( psEbookData -> pnEbookId );
}

/**
 * \brief free ebook list
 */
void freeEbooksList( GList *psEbooksList ) {
        g_list_free_full( psEbooksList, (GDestroyNotify) freeEbookData );
}
